# Synopsis
*exch-rate* is a simple tool to fetch currency exchange rates and convert them.

# Installation
To install, just follow these steps:
```
pip3 install exch-rate
```

To uninstall, just say:
```pip3 uninstall exch-rate```

# Usage
```exchrate usd inr```

outputs:

67.860001

# Credits
[StackOverflow Community](https://stackoverflow.com/questions/3139879/how-do-i-get-currency-exchange-rates-via-an-api-such-as-google-finance)